function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var button = require('primereact/button');
var reactGridLayout = require('react-grid-layout');
var ReactApexChart = _interopDefault(require('react-apexcharts'));
var axios = _interopDefault(require('axios'));
var overlaypanel = require('primereact/overlaypanel');
var dropdown = require('primereact/dropdown');
var dialog = require('primereact/dialog');
var ripple = require('primereact/ripple');
var uuid = require('uuid');

var Tools = /*#__PURE__*/function () {
  function Tools() {}

  Tools.GetLogitudeURL = function GetLogitudeURL() {
    var logitude_url = location.href.replace('index.html', '');

    if (location.href.indexOf('localhost') > -1) {
      logitude_url = 'http://localhost:9996';
    } else {
      var urlArr = location.href.split("/index.html");
      var url = urlArr[0];
      url = url.replace(url.substring(url.lastIndexOf('/'), url.length), "");
      logitude_url = url;
    }

    return logitude_url;
  };

  return Tools;
}();

var ApiServices = /*#__PURE__*/function () {
  function ApiServices() {
    this._apiUrl = Tools.GetLogitudeURL();
  }

  var _proto = ApiServices.prototype;

  _proto.getByFilters = function getByFilters(api, filters) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    apiURL = this.ConcatFiltersToURL(filters, apiURL);
    return axios.get(apiURL, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.get = function get(api) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    return axios.get(apiURL, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.post = function post(api, date) {
    var token = this.getTokenFromStorage();
    var apiURL = "" + this._apiUrl + api;
    return axios.post(apiURL, date, {
      headers: {
        'Content-Type': 'application/json',
        'Token': token
      }
    });
  };

  _proto.getTokenFromStorage = function getTokenFromStorage() {
    return window.localStorage.getItem("token") || '';
  };

  _proto.ConcatFiltersToURL = function ConcatFiltersToURL(filters, urlparameters) {
    var mykeys = Object.keys(filters);
    var addtionalFiltersValues = null;

    for (var i in mykeys) {
      var propName = mykeys[i];
      var propValue = filters[propName];
      var ignoreFilter = propName.indexOf("Operator") > 0 && propValue == "Equals" || propName == "AdditionalFilters";

      if (urlparameters != "?") {
        urlparameters = urlparameters.concat('&');
      }

      if (!ignoreFilter) {
        propValue = propValue ? encodeURIComponent(propValue) : '';
        urlparameters = urlparameters.concat(propName.concat('=').concat(propValue));
      }

      if (propName == "AdditionalFilters" && propValue.length > 0) {
        addtionalFiltersValues = JSON.stringify(propValue);
      }
    }

    if (addtionalFiltersValues) {
      urlparameters = urlparameters.concat("&AdditionalFilters=").concat(addtionalFiltersValues);
    }

    return urlparameters;
  };

  return ApiServices;
}();

var DashboardAnalyticsService = /*#__PURE__*/function () {
  function DashboardAnalyticsService() {
    this.controller = 'DashboardAnalytics';
    this._ApiServices = new ApiServices();
  }

  var _proto = DashboardAnalyticsService.prototype;

  _proto.getData = function getData(widget) {
    return this._ApiServices.post("/api/" + this.controller + "/PostGetDataAnalytic", widget);
  };

  return DashboardAnalyticsService;
}();

var ApexChart = function ApexChart(props) {
  var _props$widget, _props$widget2, _props$widget3, _props$widget5;

  var _useState = React.useState({
    series: [],
    options: {}
  }),
      args = _useState[0],
      serArgs = _useState[1];

  React.useEffect(function () {
    console.log('useEffect ApexChart', props.widget);
    var dashboardAnalyticsService = new DashboardAnalyticsService();
    dashboardAnalyticsService.getData(props.widget).then(function (result) {
      var data = getChartOptions(result.data);
      serArgs(data);
    });
  }, [props.widget, (_props$widget = props.widget) === null || _props$widget === void 0 ? void 0 : _props$widget.EntityId, (_props$widget2 = props.widget) === null || _props$widget2 === void 0 ? void 0 : _props$widget2.Filters, (_props$widget3 = props.widget) === null || _props$widget3 === void 0 ? void 0 : _props$widget3.WidgetMeasures]);

  var lineOptoins = function lineOptoins(values) {
    var series = [];
    var categories = [];

    if (values && values[0]) {
      var s = values[0].SeriesMeasureVulues.map(function (z) {
        return z.Value;
      });
      series = values.map(function (e) {
        return {
          data: e.SeriesMeasureVulues.map(function (z) {
            return z.Value;
          })
        };
      });
      categories = values[0].SeriesMeasureVulues.map(function (e) {
        return e.Label;
      });
    }

    return {
      series: series,
      options: {
        chart: {
          height: 350,
          type: 'line',
          zoom: {
            enabled: false
          }
        },
        dataLabels: {
          enabled: false
        },
        stroke: {
          curve: 'straight'
        },
        title: {
          text: 'Product Trends by Month',
          align: 'left'
        },
        grid: {
          row: {
            colors: ['#f3f3f3', 'transparent'],
            opacity: 0.5
          }
        },
        xaxis: {
          categories: categories
        }
      }
    };
  };

  var barOptoins = function barOptoins(values) {
    var series = [{
      data: []
    }];
    var categories = [];

    if (values && values[0]) {
      var s = values[0].SeriesMeasureVulues.map(function (z) {
        return z.Value;
      });
      series = values.map(function (e) {
        return {
          data: e.SeriesMeasureVulues.map(function (z) {
            return z.Value;
          })
        };
      });
      categories = values[0].SeriesMeasureVulues.map(function (e) {
        return e.Label;
      });
    }

    return {
      series: series,
      options: {
        chart: {
          type: 'bar',
          height: 430
        },
        plotOptions: {
          bar: {
            horizontal: true,
            dataLabels: {
              position: 'top'
            }
          }
        },
        dataLabels: {
          enabled: true,
          offsetX: -6,
          style: {
            fontSize: '12px',
            colors: ['#fff']
          }
        },
        stroke: {
          show: true,
          width: 1,
          colors: ['#fff']
        },
        tooltip: {
          shared: true,
          intersect: false
        },
        xaxis: {
          categories: categories
        }
      }
    };
  };

  var pieOptoins = function pieOptoins(values) {
    var series = [];
    var labels = [];

    if (values && values[0]) {
      series = values[0].SeriesMeasureVulues.map(function (e) {
        return e.Value;
      });
      labels = values[0].SeriesMeasureVulues.map(function (e) {
        return e.Label;
      });
    }

    return {
      series: series,
      options: {
        chart: {
          type: 'pie'
        },
        labels: labels
      }
    };
  };

  var donutOptoins = function donutOptoins(values) {
    var series = [];
    var labels = [];

    if (values && values[0]) {
      series = values[0].SeriesMeasureVulues.map(function (e) {
        return e.Value;
      });
      labels = values[0].SeriesMeasureVulues.map(function (e) {
        return e.Label;
      });
    }

    return {
      series: series,
      options: {
        chart: {
          width: 380,
          type: 'donut'
        },
        dataLabels: {
          enabled: false
        },
        responsive: [{
          breakpoint: 480,
          options: {
            chart: {
              width: 200
            },
            legend: {
              show: false
            }
          }
        }],
        legend: {
          position: 'right',
          offsetY: 0,
          height: 230
        },
        labels: labels
      }
    };
  };

  var handelNullLabels = function handelNullLabels(values) {
    values.forEach(function (element) {
      element.SeriesMeasureVulues.forEach(function (value) {
        if (!value.Label || value.Label == '') value.Label = 'Not defined';
      });
    });
  };

  var getChartOptions = function getChartOptions(values) {
    var _props$widget4;

    handelNullLabels(values);

    switch ((_props$widget4 = props.widget) === null || _props$widget4 === void 0 ? void 0 : _props$widget4.TypeCode) {
      case 'bar':
        return barOptoins(values);

      case 'line':
        return lineOptoins(values);

      case 'pie':
        return pieOptoins(values);

      case 'donut':
        return donutOptoins(values);
    }

    return barOptoins(values);
  };

  return React__default.createElement(ReactApexChart, {
    options: args === null || args === void 0 ? void 0 : args.options,
    series: args === null || args === void 0 ? void 0 : args.series,
    type: (_props$widget5 = props.widget) === null || _props$widget5 === void 0 ? void 0 : _props$widget5.TypeCode,
    height: "100%",
    width: "100%"
  });
};

var WidgetCard = function WidgetCard(props, state) {
  var _props$widget;

  var moreBtnToggle = React.useRef(null);

  var _useState = React.useState(true),
      loading = _useState[0],
      setLoading = _useState[1];

  React.useEffect(function () {
    setTimeout(function () {
      setLoading(false);
    }, 500);
  }, []);

  var editWidget = function editWidget() {
    var _moreBtnToggle$curren;

    (_moreBtnToggle$curren = moreBtnToggle.current) === null || _moreBtnToggle$curren === void 0 ? void 0 : _moreBtnToggle$curren.hide();
    props.editBtnClicked(props.widget);
  };

  return React__default.createElement("div", {
    className: "panel",
    key: props.el.i
  }, React__default.createElement("header", null, React__default.createElement("h1", null, ((_props$widget = props.widget) === null || _props$widget === void 0 ? void 0 : _props$widget.Title) || "not set"), props.isInEditMode ? React__default.createElement(button.Button, {
    icon: "pi pi-ellipsis-v",
    className: "p-button-lg p-button-rounded p-button-text",
    onClick: function onClick(e) {
      var _moreBtnToggle$curren2;

      return (_moreBtnToggle$curren2 = moreBtnToggle.current) === null || _moreBtnToggle$curren2 === void 0 ? void 0 : _moreBtnToggle$curren2.toggle(e);
    }
  }) : null, React__default.createElement(overlaypanel.OverlayPanel, {
    ref: moreBtnToggle,
    className: "buttons-overlay"
  }, React__default.createElement("div", {
    className: "buttons-list"
  }, React__default.createElement("div", {
    onClick: editWidget
  }, " Edit "), React__default.createElement("div", {
    onClick: function onClick() {
      var _props$widget2;

      return props.deleteBtnClicked((_props$widget2 = props.widget) === null || _props$widget2 === void 0 ? void 0 : _props$widget2.key);
    }
  }, "Remove")))), React__default.createElement("div", {
    className: "dl-dashboard-widget"
  }, loading ? null : React__default.createElement(ApexChart, {
    widget: props.widget
  })));
};

var ResponsiveReactGridLayout = reactGridLayout.WidthProvider(reactGridLayout.Responsive);

var DashboardDesigner = function DashboardDesigner(props) {
  var array12 = Array.from({
    length: 12
  }).fill(null);
  var minimumPlaceholderRowsCount = 12;

  var _useState = React.useState({
    lg: []
  }),
      layouts = _useState[0],
      setLayouts = _useState[1];

  var _useState2 = React.useState(Array.from({
    length: minimumPlaceholderRowsCount
  }).fill(null)),
      placeholderRowsArray = _useState2[0],
      setplaceholderRowsArray = _useState2[1];

  var _useState3 = React.useState(true),
      firstChange = _useState3[0],
      setFirstChange = _useState3[1];

  var _useState4 = React.useState(undefined),
      dateFilter = _useState4[0];

  var _useState5 = React.useState(false),
      isInEditMode = _useState5[0],
      setisInEditMode = _useState5[1];

  var _useState6 = React.useState({
    lg: []
  }),
      widgets = _useState6[0],
      setWidgets = _useState6[1];

  React.useEffect(function () {
    setFirstChange(true);
    console.log('useEffect setLayouts');
    setLayouts({});
    setLayouts(createLayout());
    setWidgets(props.dashboardLayouts);
  }, [props.dashboardLayouts]);

  var createLayout = function createLayout() {
    var layout = {
      lg: []
    };
    props.dashboardLayouts.lg.map(function (w) {
      return w.Layout;
    }).forEach(function (e) {
      layout.lg.push(e);
    });
    return layout;
  };

  React.useEffect(function () {
    setisInEditMode(props.editMode);
  }, [props.editMode]);

  function _onLayoutChange(layout, changedLayouts) {
    console.log(layout, layouts);

    if (firstChange) {
      setFirstChange(false);
      return;
    }

    setLayouts(changedLayouts);
    UpdatePlaceholderDimensions();
    props.onLayoutChange(changedLayouts);
  }

  function deletePanel(id) {
    console.log('deletePanel(id)', id);
    var newLayouts = {
      lg: layouts.lg.filter(function (e) {
        return e.i != id;
      })
    };
    setLayouts(newLayouts);
    var newWidgets = {
      lg: widgets.lg.filter(function (e) {
        return e.key != id;
      })
    };
    setWidgets(newWidgets);
    props.onLayoutChange(newLayouts);
  }

  function editWidget(widget) {
    widget.ChangeSetOp = 'Update';
    props.openEditWidget(widget);
  }

  function UpdatePlaceholderDimensions() {
    var _gridLayout$;

    console.log('UpdatePlaceholderDimensions', layouts);
    var gridLayout = document.getElementsByClassName('react-grid-layout');
    if (!gridLayout) return;
    var gridElementHeight = (_gridLayout$ = gridLayout[0]) === null || _gridLayout$ === void 0 ? void 0 : _gridLayout$.clientHeight;
    var newPlaceholderRows = Math.floor(gridElementHeight / layoutGridProps.rowHeight);
    newPlaceholderRows = newPlaceholderRows < minimumPlaceholderRowsCount ? minimumPlaceholderRowsCount : newPlaceholderRows;
    setplaceholderRowsArray(Array.from({
      length: newPlaceholderRows
    }).fill(null));
  }

  return React__default.createElement("div", {
    className: "dl-full-hight"
  }, React__default.createElement("div", {
    className: "dl-box"
  }, React__default.createElement("div", {
    className: "dl-row dl-content"
  }, React__default.createElement("div", {
    className: "dl-grid-container"
  }, React__default.createElement("div", {
    className: "dl-grid dl-grid--bordered"
  }, props.editMode ? placeholderRowsArray.map(function (e, i) {
    return array12.map(function (e, i) {
      return React__default.createElement("div", {
        key: i,
        style: {
          height: layoutGridProps.rowHeight
        }
      });
    });
  }) : null), React__default.createElement(ResponsiveReactGridLayout, Object.assign({}, layoutGridProps, {
    layouts: layouts,
    compactType: "vertical",
    isDraggable: isInEditMode,
    isResizable: isInEditMode,
    onWidthChange: function onWidthChange() {
      return UpdatePlaceholderDimensions();
    },
    onLayoutChange: function onLayoutChange(layout, layouts) {
      return _onLayoutChange(layout, layouts);
    }
  }), widgets.lg.map(function (widget) {
    var _widget$Layout, _widget$Layout2;

    return React__default.createElement("div", {
      key: (_widget$Layout = widget.Layout) === null || _widget$Layout === void 0 ? void 0 : _widget$Layout.i
    }, React__default.createElement(WidgetCard, {
      isInEditMode: isInEditMode,
      key: (_widget$Layout2 = widget.Layout) === null || _widget$Layout2 === void 0 ? void 0 : _widget$Layout2.i,
      widget: widget,
      el: widget,
      dateFilter: dateFilter,
      editBtnClicked: editWidget,
      deleteBtnClicked: deletePanel
    }));
  }))))));
};

var layoutGridProps = {
  rowHeight: 50,
  className: "layout",
  cols: {
    lg: 12,
    md: 6,
    sm: 2,
    xs: 1,
    xxs: 1
  },
  useCSSTransforms: true
};

var DashBoardService = /*#__PURE__*/function () {
  function DashBoardService() {
    this.tableName = 'DashBoard';
    this._ApiServices = new ApiServices();
  }

  var _proto = DashBoardService.prototype;

  _proto.getDataByFilters = function getDataByFilters(filters) {
    return this._ApiServices.getByFilters("/api/" + this.tableName + "Views/getbyfilters?", filters);
  };

  _proto.add = function add(data) {
    return this._ApiServices.post("/api/DashBoards", data);
  };

  return DashBoardService;
}();

var WidgetTypeListService = /*#__PURE__*/function () {
  function WidgetTypeListService() {
    this._ApiServices = new ApiServices();
  }

  var _proto = WidgetTypeListService.prototype;

  _proto.getDataByFilters = function getDataByFilters(filters) {
    return this._ApiServices.getByFilters("/api/WidgetTypeViews/getbyfilters?", filters);
  };

  _proto.getAll = function getAll() {
    return this._ApiServices.get("/api/WidgetTypeViews/getall");
  };

  return WidgetTypeListService;
}();

function deepClone(obj) {
  return JSON.parse(JSON.stringify(obj));
}

var Dashboard = function Dashboard(props) {
  var _props$token;

  var newWidgetWidth = 3;
  var newWidgetHeight = 5;

  var _useState = React.useState([]),
      dashbords = _useState[0],
      setDashbords = _useState[1];

  var _useState2 = React.useState(undefined),
      currentDashbord = _useState2[0],
      setCurrentDashbord = _useState2[1];

  var _useState3 = React.useState(undefined),
      beforEditDashbord = _useState3[0],
      setBeforEditDashbord = _useState3[1];

  var _useState4 = React.useState(false),
      hasChanges = _useState4[0],
      setHasChanges = _useState4[1];

  var _useState5 = React.useState(false),
      isInEditMode = _useState5[0],
      setIsInEditMode = _useState5[1];

  var _useState6 = React.useState(),
      WidgetTypes = _useState6[0],
      setWidgetTypes = _useState6[1];

  var _useState7 = React.useState({
    lg: []
  }),
      layouts = _useState7[0],
      setLayouts = _useState7[1];

  var _useState8 = React.useState(false),
      cancelConfirmDialog = _useState8[0],
      setCancelConfirmDialog = _useState8[1];

  var dashboardMoreButtonToggle = React.createRef();
  var dashboardService = new DashBoardService();
  var widgetTypeListService = new WidgetTypeListService();
  React.useEffect(function () {
    getWidgetTypes();
    props.dataBinding.onGetDashboard.subscribe(function (e) {
      console.log('onGetDashboard.subscribe', e);
      setCurrentDashbord(e);
      applyLayouts(e);
    });
    props.dataBinding.onGetAllDashboards.subscribe(function (e) {
      console.log('onGetAllDashboard.subscribe', e);
      setDashbords(e);
    });
    props.dataBinding.onAddUpdateWidget.subscribe(function (isUpdated) {
      if (!isUpdated) return;
      setHasChanges(true);
    });
  }, []);
  if ((props === null || props === void 0 ? void 0 : (_props$token = props.token) === null || _props$token === void 0 ? void 0 : _props$token.length) > 0) localStorage.setItem("token", props === null || props === void 0 ? void 0 : props.token);

  var getWidgetTypes = function getWidgetTypes() {
    widgetTypeListService.getAll().then(function (data) {
      setWidgetTypes(data.data);
    });
  };

  var EditDashBoard = function EditDashBoard() {
    var _dashboardMoreButtonT;

    props.openAddEditDashboard(currentDashbord);
    dashboardMoreButtonToggle === null || dashboardMoreButtonToggle === void 0 ? void 0 : (_dashboardMoreButtonT = dashboardMoreButtonToggle.current) === null || _dashboardMoreButtonT === void 0 ? void 0 : _dashboardMoreButtonT.hide();
  };

  var addWidget = function addWidget(widgetCode) {
    var position = EvaluateNewWidgetPosition();
    props.openAddEditWidget({
      TypeCode: widgetCode,
      StartPotistion: position.x + "," + position.y,
      EndPosition: position.w + "," + position.h,
      ChangeSetOp: 'Insert'
    });
  };

  var EvaluateNewWidgetPosition = function EvaluateNewWidgetPosition() {
    var widgetYPosition = 0;
    var widgetXPosition = 0;
    var layout = layouts["lg"].map(function (e) {
      return e.Layout;
    });
    var maxY = layout.reduce(function (max, widget) {
      if (widget && widget.y > max) max = widget.y;
      return max;
    }, 0);

    var _loop = function _loop(y) {
      var widgetsRow = layout.filter(function (d) {
        return (d === null || d === void 0 ? void 0 : d.y) == y;
      });
      var lastWidgetStartXPosition = Math.max.apply(Math, widgetsRow.map(function (a) {
        return a === null || a === void 0 ? void 0 : a.x;
      }));
      var lastWidget = widgetsRow.find(function (a) {
        return (a === null || a === void 0 ? void 0 : a.x) == lastWidgetStartXPosition;
      });

      if (lastWidget) {
        var lastWidgetEndXPosition = lastWidgetStartXPosition + lastWidget.w;
        var availableHorizontalSlots = layoutGridProps.cols.lg - lastWidgetEndXPosition;

        if (availableHorizontalSlots >= newWidgetWidth) {
          widgetYPosition = y;
          widgetXPosition = lastWidgetEndXPosition;
          return {
            v: {
              x: widgetXPosition,
              y: widgetYPosition,
              w: newWidgetWidth,
              h: newWidgetHeight
            }
          };
        } else {
          widgetYPosition = y + 1;
        }
      } else {
        widgetYPosition = y + 1;
      }
    };

    for (var y = 0; y <= maxY; y++) {
      var _ret = _loop(y);

      if (typeof _ret === "object") return _ret.v;
    }

    return {
      x: widgetXPosition,
      y: widgetYPosition,
      w: newWidgetWidth,
      h: newWidgetHeight
    };
  };

  var editLayout = function editLayout() {
    var _dashboardMoreButtonT2;

    setIsInEditMode(true);
    setHasChanges(false);
    dashboardMoreButtonToggle === null || dashboardMoreButtonToggle === void 0 ? void 0 : (_dashboardMoreButtonT2 = dashboardMoreButtonToggle.current) === null || _dashboardMoreButtonT2 === void 0 ? void 0 : _dashboardMoreButtonT2.hide();
    setBeforEditDashbord(deepClone(currentDashbord));
  };

  var save = function save() {
    setIsInEditMode(false);
    console.log('onSaveDashboard > ', currentDashbord);
    props.onSaveDashboard(currentDashbord);
    onHide();
    setHasChanges(false);
  };

  var cancelSave = function cancelSave() {
    if (!hasChanges) {
      setIsInEditMode(false);
      setHasChanges(false);
    } else {
      setCancelConfirmDialog(true);
    }
  };

  var dontSave = function dontSave() {
    setHasChanges(false);
    setIsInEditMode(false);
    props.dataBinding.onGetDashboard.next(beforEditDashbord);
    setCancelConfirmDialog(false);
  };

  var changeDashboard = function changeDashboard(event) {
    if (event.value == (currentDashbord === null || currentDashbord === void 0 ? void 0 : currentDashbord.Id)) return;
    var dasboard = dashbords.find(function (e) {
      return e.Id == event.value;
    });
    props.onChangeDashboard(dasboard);
    props.dataBinding.onGetDashboard.next(dasboard);
  };

  var applyLayouts = function applyLayouts(dashbord) {
    if (!(dashbord !== null && dashbord !== void 0 && dashbord.Widgets)) return;
    var layout = {
      lg: []
    };
    dashbord === null || dashbord === void 0 ? void 0 : dashbord.Widgets.map(function (widget) {
      if (widget.Id && widget.Id.length > 0) widget.key = widget.Id;else widget.key = uuid.v4();
      widget.Layout = {
        minH: 5,
        minW: 3,
        i: widget.key,
        w: +widget.EndPosition.split(',')[0],
        h: +widget.EndPosition.split(',')[1],
        x: +widget.StartPotistion.split(',')[0],
        y: +widget.StartPotistion.split(',')[1]
      };
      layout.lg.push(widget);
    });
    console.log('setLayouts -- > ', layout);
    setLayouts(layout);
  };

  var updateWidgets = function updateWidgets(layouts) {
    console.log('updateWidgets = (layouts:Layouts', layouts);
    var layoutsDic = {};
    Object.keys(layouts).forEach(function (sizeType) {
      if (layouts[sizeType].length > 0) {
        layouts[sizeType].map(function (layout) {
          layoutsDic[layout.i] = layout;
        });
        return;
      }
    });
    var widgets = [];
    currentDashbord === null || currentDashbord === void 0 ? void 0 : currentDashbord.Widgets.forEach(function (widget) {
      if (layoutsDic[widget.key]) {
        widget.StartPotistion = layoutsDic[widget.key].x + "," + layoutsDic[widget.key].y;
        widget.EndPosition = layoutsDic[widget.key].w + "," + layoutsDic[widget.key].h;
        widgets.push(widget);
      }
    });

    if (currentDashbord) {
      currentDashbord.Widgets = widgets;
    }

    console.log('after update widget', currentDashbord);
    setHasChanges(true);
  };

  var renderCancelConfirmDialogFooter = function renderCancelConfirmDialogFooter() {
    return React.createElement("div", {
      className: 'dl-flex-row-end'
    }, React.createElement(button.Button, {
      label: "Cancel",
      onClick: function onClick() {
        return onHide();
      },
      className: "p-button-secondary"
    }), React.createElement(button.Button, {
      label: "Don't Save",
      onClick: function onClick() {
        return dontSave();
      },
      className: "p-button-secondary"
    }), React.createElement(button.Button, {
      label: "Save",
      onClick: function onClick() {
        return save();
      },
      autoFocus: true,
      className: "p-button-warning"
    }));
  };

  var onHide = function onHide() {
    setCancelConfirmDialog(false);
  };

  return React.createElement("div", {
    className: 'dl-full-hight'
  }, React.createElement("div", {
    className: 'dl-dashboard-header dl-card'
  }, React.createElement("div", {
    className: 'dl-flex-row dl-custom-btn'
  }, React.createElement("div", {
    className: 'dl-title-1'
  }, currentDashbord === null || currentDashbord === void 0 ? void 0 : currentDashbord.Name), React.createElement(button.Button, {
    icon: "pi pi-ellipsis-v",
    onClick: function onClick(e) {
      var _dashboardMoreButtonT3;

      return dashboardMoreButtonToggle === null || dashboardMoreButtonToggle === void 0 ? void 0 : (_dashboardMoreButtonT3 = dashboardMoreButtonToggle.current) === null || _dashboardMoreButtonT3 === void 0 ? void 0 : _dashboardMoreButtonT3.toggle(e);
    },
    className: "p-button p-button-icon-only p-button-rounded p-button-text"
  }, React.createElement(ripple.Ripple, null)), React.createElement(overlaypanel.OverlayPanel, {
    ref: dashboardMoreButtonToggle,
    className: "buttons-overlay"
  }, React.createElement("div", {
    className: "buttons-list"
  }, React.createElement("div", {
    onClick: function onClick() {
      return EditDashBoard();
    }
  }, "Edit"), React.createElement("div", {
    onClick: editLayout
  }, "Edit Layout")))), React.createElement("div", {
    className: 'dl-flex-row'
  }, !isInEditMode ? React.createElement("div", {
    className: 'dl-flex-row'
  }, React.createElement("div", {
    style: {
      width: "161px"
    }
  }, React.createElement(dropdown.Dropdown, {
    value: [],
    options: dashbords,
    optionValue: "Id",
    optionLabel: "Name",
    onChange: changeDashboard,
    placeholder: "Choose Dashboard",
    optionDisabled: function optionDisabled(option) {
      return option === null || option === void 0 ? void 0 : option.Disabled;
    },
    scrollHeight: "300px",
    style: {
      width: '100%'
    }
  })), React.createElement(button.Button, {
    icon: "pi pi-plus",
    onClick: function onClick() {
      return props.openAddEditDashboard(undefined);
    },
    className: "dl-dashboard-add p-button-rounded p-button-success"
  })) : null, isInEditMode ? React.createElement("div", {
    className: 'dl-flex-row'
  }, React.createElement(button.Button, {
    label: "Cancel",
    className: "p-button-secondary dl-m-r-s dl-m-t-8",
    onClick: cancelSave
  }), React.createElement(dialog.Dialog, {
    header: "Unsaved Changes",
    visible: cancelConfirmDialog,
    style: {
      width: '50vw'
    },
    footer: renderCancelConfirmDialogFooter(),
    onHide: onHide
  }, React.createElement("p", null, "This Dashboard has unsaved changes do you want to save it?")), hasChanges ? React.createElement(button.Button, {
    label: "Save",
    form: "frm",
    onClick: save,
    autoFocus: true,
    className: "p-button-warning dl-m-t-8"
  }) : null, !hasChanges ? React.createElement(button.Button, {
    label: "Save",
    form: "frm",
    onClick: save,
    autoFocus: true,
    className: "p-button-secondary dl-m-t-8"
  }) : null, React.createElement("div", {
    style: {
      width: '192px',
      marginLeft: '15px'
    }
  }, React.createElement(dropdown.Dropdown, {
    options: WidgetTypes,
    optionValue: "Code",
    optionLabel: "Name",
    onChange: function onChange(e) {
      return addWidget(e.value);
    },
    placeholder: "Add Component",
    optionDisabled: function optionDisabled(option) {
      return option === null || option === void 0 ? void 0 : option.Disabled;
    },
    scrollHeight: "300px"
  }))) : null)), React.createElement("div", {
    className: 'dl-dashboard-body'
  }, React.createElement(DashboardDesigner, {
    editMode: isInEditMode,
    onLayoutChange: updateWidgets,
    dashboardLayouts: layouts,
    openEditWidget: function openEditWidget(widget) {
      return props.openAddEditWidget(widget);
    }
  })));
};

module.exports = Dashboard;
//# sourceMappingURL=index.js.map
